## 6th Dec 2021

## The purpose of this script is to re-analyse the Bat monitoring best 
## practices data while addressing the comments of reviewers. Namely: 

# 1:
  #A "use a modelling approach that assumes you already know when activity 
  # will peak" -- agreed- run all models, not after perceived peak

  #B have removed bad weather days from the analysis but objectives to determine 
  # whether it affects -- agreed, ZI should fix

  #C model structures that don't force you to break down hour-by hour. 
  # (R2 also brings this up)
  # -- Got to think about this. 

# 2: 
  #D don't check for collinearity of predictors -- agreed. 

  #E model predictions (monotonic increase) look different to data (unimodal 
  # peak), suggest a polynomial term
  # -- yeah, not good models clearly. polyunomial terms will be problematic 
  # if ZI doen't fix hetreroskedasticity. 

  #F sites used as random effect,  overfit? instead, site type as fixed effect. 
  # -- sounds good,. lets give it a go. 

  #G model as zero-inflation rather than removing probably meaningful zeroes. 
  # use zero inflated rather than hurdle models. --- YES agreed

  #H a measure of prediction error is more appropriate than AIC. check caret. 
  # -- yup, sounds right. will have a look. 

  #I more complex models that incorporate multiple variables. -=-- YES

  #J provide R2 -- sure. 

#############################################################################

#set up space
rm(list=ls())
setwd("R:/R5001-6000/R5901-5950/5913 CH Best practice bat monitoring")
      ## I think this code might bug out on the back end in this system 
      ## refind pathway in code> source file> select a file in the wd you want

#import data and packages
library(pscl) ## for Zero Inflation models
library(caret)## suggested by reviewer two for prediction success measures
library(corrplot) ## for correlation plots
library(RColorBrewer)
library(ggplot2)
library(lmtest) ##likelihood ratio test
library(performance) ##more complete model comparison 
library(modelr)
d <-read.csv("./WX analysis 2/WX3 plus difference corrected_21_zeroes added.csv")

### check for multicollinearity
M <-cor(d[c(12, 14, 79:89,94, 110, 142, 158)],) ### find additional predictors using colnames(d)

pdf("./Justyna Analyses/predictor correlations.pdf")
corrplot(M, type = "upper", order = "hclust",
         col = brewer.pal(n = 8, name="RdYlBu"),
         addCoef.col = 'grey', tl.cex=0.5, number.cex = 0.7)
dev.off()

##### need to think about the issue of pseudoreplication
summary(as.factor(d$Location))

#################### MODELLING ####################################

m5 <- zeroinfl(Tot.pass ~ poly(max_day_temp,2) + RHSS| poly(TSS,2) + as.factor(Habitat2), 
               dist = "poisson", 
               data = d)

plot(residuals(m5))
summary(m5)

################ MODEL TESTING          https://stats.idre.ucla.edu/r/dae/zip/
  #This model fits the data significantly better than the null model, i.e., the 
  #intercept-only model. To show that this is the case, we can compare with the 
  #current model to a null model 

summary(mnull <-  glm(Tot.pass ~ poly(TSS,2)+ WSSS+ tot.day_rain + RHSS + 
                        poly(d_mean_night_temp_night_prior,2) + poly(d_total_night_rain_night_prior,2), ###this is m6 structure
              family = poisson, 
              data = d))
plot(m5)
vuong(m5, mnull)
  #The Vuong test compares the zero-inflated model with an ordinary Poisson 
  #regression model. In this example, we can see that our test statistic is 
  #significant, indicating that the zero-inflated model is superior to the 
  #standard Poisson model.

#################################################################
###### plotting outputs #########################################
#################################################################

d$predm5 = predict(m5)

pdf("./Justyna Analyses/m5_predictions.pdf")
par (mfrow = c (3,3))
plot(Tot.pass ~ RHSS , ylab = "Total passes",
     pch = 16, data = d, main = "Observations")
plot(factor(Tot.pass > 0, levels = c(FALSE, TRUE), labels = c("=0", ">0")) ~ RHSS,
     data = d, ylab = "", main = "Zero inflation")
plot(predm5 ~ RHSS,  data = d, ylab = "", main = "Model predictions")

plot(Tot.pass ~ max_day_temp , ylab = "Total passes",
     pch = 16, data = d)
plot(factor(Tot.pass > 0, levels = c(FALSE, TRUE), labels = c("=0", ">0")) ~ max_day_temp,
     data = d, ylab = "")
plot(predm5 ~ max_day_temp, data = d, ylab = "")

plot(Tot.pass ~ TSS , pch = 16, data = d)
plot(factor(Tot.pass > 0, levels = c(FALSE, TRUE), labels = c("=0", ">0")) ~ TSS,
     data = d, ylab = "")
plot(predm5 ~ TSS,  data = d, ylab = "")
dev.off()

########################################################
################ predictor selection ###################
########################################################
pdf("./Justyna Analyses/trends_env.pdf")
par(mfrow = c(3,3))
for (i in names(d[c(12, 14, 79:89,94, 110, 142, 158)]) ){
plot(Tot.pass ~ d[[i]], 
     xlab = i, pch = 16,
               data = d)
}
dev.off()

##building full model with hand selected representatives of ewach grouping. 
##then dropping terms
m1 <- zeroinfl(Tot.pass ~ poly(TSS,2)+ WSSS+ tot.day_rain + RHSS + 
                 poly(d_mean_night_temp_night_prior,2) + poly(d_total_night_rain_night_prior,2)|
                 
                 TSS + WSSS + tot.day_rain + RHSS + 
                 d_mean_night_temp_night_prior + d_total_night_rain_night_prior+ 
                 as.factor(Habitat2), 
               dist = "poisson", 
               data = d)
summary(m1)
 #removing WSSS from zeroinfl
m2 <- zeroinfl(Tot.pass ~ poly(TSS,2)+ WSSS+ tot.day_rain + RHSS + 
                 poly(d_mean_night_temp_night_prior,2) + poly(d_total_night_rain_night_prior,2)|
                 
                 TSS + tot.day_rain + RHSS + 
                 d_mean_night_temp_night_prior + d_total_night_rain_night_prior+ 
                 as.factor(Habitat2), 
               dist = "poisson", 
               data = d)
summary(m2)
#removing RHSS from zeroinfl
m3 <- zeroinfl(Tot.pass ~ poly(TSS,2)+ WSSS+ tot.day_rain + RHSS + 
                 poly(d_mean_night_temp_night_prior,2) + poly(d_total_night_rain_night_prior,2)|
                 
                 TSS + tot.day_rain +  
                 d_mean_night_temp_night_prior + d_total_night_rain_night_prior+ 
                 as.factor(Habitat2), 
               dist = "poisson", 
               data = d)
summary(m3)

#removing d_total_night_rain_night_prior from zeroinfl
m4 <- zeroinfl(Tot.pass ~ poly(TSS,2)+ WSSS+ tot.day_rain + RHSS + 
                 poly(d_mean_night_temp_night_prior,2) + poly(d_total_night_rain_night_prior,2)|
                 
                 TSS + tot.day_rain +  
                 d_mean_night_temp_night_prior + 
                 as.factor(Habitat2), 
               dist = "poisson", 
               data = d)
summary(m4)

#removing tot.day_rain  from zeroinfl
m6 <- zeroinfl(Tot.pass ~ poly(TSS,2)+ WSSS+ tot.day_rain + RHSS + 
                 poly(d_mean_night_temp_night_prior,2) + poly(d_total_night_rain_night_prior,2)|
                 
                 TSS +
                 d_mean_night_temp_night_prior + 
                 as.factor(Habitat2), 
               dist = "poisson", 
               data = d)
summary(m6) #################### all significant
str(m6)
#count model intercept not significant -- overparameterized? 
#removing RHSS from that model -- smallest impact on predictions (ie |smallest intercept|)
m7 <- zeroinfl(Tot.pass ~ poly(TSS,2)+ WSSS+ tot.day_rain + 
                 poly(d_mean_night_temp_night_prior,2) + poly(d_total_night_rain_night_prior,2)|
                 
                 TSS +
                 d_mean_night_temp_night_prior + 
                 as.factor(Habitat2), 
               dist = "poisson", 
               data = d)
summary(m7)

#removing now non-significant d_mean_night_temp_night_prior from zeroinbfl model
m8 <- zeroinfl(Tot.pass ~ poly(TSS,2)+ WSSS+ tot.day_rain + 
                 poly(d_mean_night_temp_night_prior,2) + poly(d_total_night_rain_night_prior,2)|
                 
                 TSS + 
                 as.factor(Habitat2), 
               dist = "poisson", 
               data = d)
summary(m8) ###################YUP I THINK ITS DONE

#trying to remove WSSS which has negigible impact on prediction
m9 <- zeroinfl(Tot.pass ~ poly(TSS,2)+ tot.day_rain + 
                 poly(d_mean_night_temp_night_prior,2) + poly(d_total_night_rain_night_prior,2)|
                 
                 TSS + 
                 as.factor(Habitat2), 
               dist = "poisson", 
               data = d)
summary(m9) 
#now tot.day_rain because it is no longer significant (negligible impact before too)
m10 <- zeroinfl(Tot.pass ~ poly(TSS,2)+ 
                 poly(d_mean_night_temp_night_prior,2) + poly(d_total_night_rain_night_prior,2)|
                 
                 TSS + 
                 as.factor(Habitat2), 
               dist = "poisson", 
               data = d)
summary(m10) 
##trying to remove polynomial for TSS from m6 
m11 <- zeroinfl(Tot.pass ~ TSS+ WSSS+ tot.day_rain + RHSS + 
                 poly(d_mean_night_temp_night_prior,2) + poly(d_total_night_rain_night_prior,2)|
                 
                 TSS +
                 d_mean_night_temp_night_prior + 
                 as.factor(Habitat2), 
               dist = "poisson", 
               data = d)

################ MODEL TESTING          
vuong(m8, mnull)
vuong (m8, m6) ###m6 performs better..... should still stick to m6
vuong(m6, mnull)

lrtest(m8, mnull) ### likelihhod ratio test
lrtest(m8, m6)
lrtest(m6, mnull)
lrtest(m6, m10)  ## no, not better. SHould stick to m8
compare_performance(m1, m2, m3, m4, m5, m6,m7, m8, m9, m10, m11, mnull)
summary(m6)
summary(m11) 
lrtest(m6, m11)  ###no, m6 still better.
r2(m6)
r2(m11)
#################################################################
###### plotting outputs #########################################
#################################################################


d$predm6 = predict(m6, type = "response")

pdf("./Justyna Analyses/m6_predictions.pdf")
par (mfrow = c (4,3))

par(mai=c(1, 0.6, 0.2, 0.1))
plot(Tot.pass ~ TSS , ylab = "Total passes",  xlab = "", main = "Observations", pch = 16, data = d)
par(mai=c(1, 0.3, 0.2, 0.5))
plot(factor(Tot.pass > 0, levels = c(FALSE, TRUE), labels = c("=0", ">0")) ~ TSS,
     data = d, ylab = "", xlab = expression(paste("Temperature at sunset (", degree, "C)" )), main = "Zero inflation")
par(mai=c(1, 0, 0.2, 0.5))
plot(predm6 ~ TSS,  data = d, ylab = "", xlab = "", main = "Model predictions", yaxt = "n")
axis(4)

par(mai=c(1, 0.6, 0.2, 0.1))
plot(Tot.pass ~ WSSS , ylab = "Total passes", xlab = "", pch = 16, data = d)
par(mai=c(1, 0.3, 0.2, 0.5))
plot(factor(Tot.pass > 0, levels = c(FALSE, TRUE), labels = c("=0", ">0")) ~ WSSS,
     data = d, ylab = "", xlab = expression(paste("Windspeed at sunset (kmh"^{-1}, ")")), col = "white")
par(mai=c(1, 0, 0.2, 0.5))
plot(predm6 ~ WSSS,  data = d, xlab = "", ylab = "", yaxt = "n")
axis(4)

par(mai=c(1, 0.6, 0.2, 0.1))
plot(Tot.pass ~ tot.day_rain , xlab = "",  ylab = "Total passes", pch = 16, data = d)
par(mai=c(1, 0.3, 0.2, 0.5))
plot(factor(Tot.pass > 0, levels = c(FALSE, TRUE), labels = c("=0", ">0")) ~ tot.day_rain,
     data = d, ylab = "", col = "white", xlab = "Precipitation (mm)")
par(mai=c(1, 0, 0.2, 0.5))
plot(predm6 ~ tot.day_rain,  data = d, xlab = "", ylab = "", yaxt = "n")
axis(4)

par(mai=c(1, 0.6, 0.2, 0.1))
plot(Tot.pass ~ RHSS ,xlab = "",  ylab = "Total passes", pch = 16, data = d)
par(mai=c(1, 0.3, 0.2, 0.5))
plot(factor(Tot.pass > 0, levels = c(FALSE, TRUE), labels = c("=0", ">0")) ~ RHSS,
     data = d, ylab = "", col = "white", xlab = "Relative humidity at sunset (%)")
par(mai=c(1, 0, 0.2, 0.5))
plot(predm6 ~ RHSS,  data = d, ylab = "",xlab = "", yaxt = "n")
axis(4)

par(mai=c(1, 0.6, 0.2, 0.1))
plot(Tot.pass ~ d_mean_night_temp_night_prior , ylab = "Total passes",
     pch = 16, data = d, xlab = "")
par(mai=c(1, 0.3, 0.2, 0.5))
plot(factor(Tot.pass > 0, levels = c(FALSE, TRUE), labels = c("=0", ">0")) ~ d_mean_night_temp_night_prior,
     data = d, ylab = "",  xlab = expression(paste(Delta," Night temperature (", mu, degree, "C)")))
par(mai=c(1, 0, 0.2, 0.5))
plot(predm6 ~ d_mean_night_temp_night_prior,  data = d, ylab = "", xlab = "")
axis(4)

par(mai=c(1, 0.6, 0.2, 0.1))
plot(Tot.pass ~ d_total_night_rain_night_prior , ylab = "Total passes", xlab = "",
     pch = 16, data = d)
par(mai=c(1, 0.3, 0.2, 0.5))
plot(factor(Tot.pass > 0, levels = c(FALSE, TRUE), labels = c("=0", ">0")) ~ d_total_night_rain_night_prior,
     data = d, ylab = "", col = "white", xlab = expression(paste(Delta," Night precipitation (mm)")))
par(mai=c(1, 0, 0.2, 0.5))
plot(predm6 ~ d_total_night_rain_night_prior,  data = d, ylab = "",  xlab = "", yaxt = "n")
axis(4)

par(mai=c(1, 0.6, 0.2, 0.1))
plot(Tot.pass ~ as.factor(Habitat2) , ylab = "Total passes", xlab = "",
     pch = 16, data = d)
par(mai=c(1, 0.3, 0.2, 0.5))
plot(factor(Tot.pass > 0, levels = c(FALSE, TRUE), labels = c("=0", ">0")) ~ as.factor(Habitat2),
     data = d, ylab = "",  xlab = "Habitat type")
par(mai=c(1, 0, 0.2, 0.5))
plot(predm6 ~ as.factor(Habitat2),  data = d, ylab = "",  xlab = "", col = "white", yaxt = "n")
axis(4)

dev.off()

#################################################################
###### plotting outputs random ##################################
#################################################################

newdat <- data_grid(d, TSS = seq_range(TSS, 1000))
newdat$WSSS <- runif(1000, min = min(d$WSSS), max = max(d$WSSS))
newdat$Habitat2 <- as.integer(runif(1000, min = 1, max = 4))
newdat$tot.day_rain <- runif(1000, min = min(d$tot.day_rain), max = max(d$tot.day_rain))
newdat$RHSS <- runif(1000, min = min(d$RHSS), max = max(d$RHSS))
newdat$d_mean_night_temp_night_prior <- runif(1000, min = min(d$d_mean_night_temp_night_prior), max = max(d$d_mean_night_temp_night_prior))
newdat$d_total_night_rain_night_prior <- runif(1000, min = min(d$d_total_night_rain_night_prior), max = max(d$d_total_night_rain_night_prior))

newdat$predm6 <- predict(m6, newdat, type = "response")


pdf("./Justyna Analyses/m6_predictions_rand.pdf")
par (mfrow = c (4,3))

par(mai=c(1, 0.6, 0.2, 0.1))
plot(Tot.pass ~ TSS , ylab = "Total passes",  xlab = "", main = "Observations", pch = 16, data = d)
par(mai=c(1, 0.3, 0.2, 0.5))
plot(factor(Tot.pass > 0, levels = c(FALSE, TRUE), labels = c("=0", ">0")) ~ TSS,
     data = d, ylab = "", xlab = expression(paste("Temperature at sunset (", degree, "C)" )), main = "Zero inflation")
par(mai=c(1, 0, 0.2, 0.5))
plot(predm6 ~ TSS,  data = newdat, ylab = "", xlab = "", main = "Model predictions", yaxt = "n")
axis(4)

par(mai=c(1, 0.6, 0.2, 0.1))
plot(Tot.pass ~ WSSS , ylab = "Total passes", xlab = "", pch = 16, data = d)
par(mai=c(1, 0.3, 0.2, 0.5))
plot(factor(Tot.pass > 0, levels = c(FALSE, TRUE), labels = c("=0", ">0")) ~ WSSS,
     data = d, ylab = "", xlab = expression(paste("Windspeed at sunset (kmh"^{-1}, ")")), col = "white")
par(mai=c(1, 0, 0.2, 0.5))
plot(predm6 ~ WSSS,  data = d, xlab = "", ylab = "", yaxt = "n")
axis(4)

par(mai=c(1, 0.6, 0.2, 0.1))
plot(Tot.pass ~ tot.day_rain , xlab = "",  ylab = "Total passes", pch = 16, data = d)
par(mai=c(1, 0.3, 0.2, 0.5))
plot(factor(Tot.pass > 0, levels = c(FALSE, TRUE), labels = c("=0", ">0")) ~ tot.day_rain,
     data = d, ylab = "", col = "white", xlab = "Day total precipitation (mm)")
par(mai=c(1, 0, 0.2, 0.5))
plot(predm6 ~ tot.day_rain,  data = newdat, xlab = "", ylab = "", yaxt = "n")
axis(4)

par(mai=c(1, 0.6, 0.2, 0.1))
plot(Tot.pass ~ RHSS ,xlab = "",  ylab = "Total passes", pch = 16, data = d)
par(mai=c(1, 0.3, 0.2, 0.5))
plot(factor(Tot.pass > 0, levels = c(FALSE, TRUE), labels = c("=0", ">0")) ~ RHSS,
     data = d, ylab = "", col = "white", xlab = "Relative humidity at sunset (%)")
par(mai=c(1, 0, 0.2, 0.5))
plot(predm6 ~ RHSS,  data = newdat, ylab = "",xlab = "", yaxt = "n")
axis(4)

par(mai=c(1, 0.6, 0.2, 0.1))
plot(Tot.pass ~ d_mean_night_temp_night_prior , ylab = "Total passes",
     pch = 16, data = d, xlab = "")
par(mai=c(1, 0.3, 0.2, 0.5))
plot(factor(Tot.pass > 0, levels = c(FALSE, TRUE), labels = c("=0", ">0")) ~ d_mean_night_temp_night_prior,
     data = d, ylab = "",  xlab = expression(paste(Delta," Night temperature (", mu, degree, "C)")))
par(mai=c(1, 0, 0.2, 0.5))
plot(predm6 ~ d_mean_night_temp_night_prior,  data = newdat, ylab = "", xlab = "")
axis(4)

par(mai=c(1, 0.6, 0.2, 0.1))
plot(Tot.pass ~ d_total_night_rain_night_prior , ylab = "Total passes", xlab = "",
     pch = 16, data = d)
par(mai=c(1, 0.3, 0.2, 0.5))
plot(factor(Tot.pass > 0, levels = c(FALSE, TRUE), labels = c("=0", ">0")) ~ d_total_night_rain_night_prior,
     data = d, ylab = "", col = "white", xlab = expression(paste(Delta," Night precipitation (mm)")))
par(mai=c(1, 0, 0.2, 0.5))
plot(predm6 ~ d_total_night_rain_night_prior,  data = d, ylab = "",  xlab = "", yaxt = "n")
axis(4)

par(mai=c(1, 0.6, 0.2, 0.1))
plot(Tot.pass ~ as.factor(Habitat2) , ylab = "Total passes", xlab = "",
     pch = 16, data = d)
par(mai=c(1, 0.3, 0.2, 0.5))
plot(factor(Tot.pass > 0, levels = c(FALSE, TRUE), labels = c("=0", ">0")) ~ as.factor(Habitat2),
     data = d, ylab = "",  xlab = "Habitat type")
par(mai=c(1, 0, 0.2, 0.5))
plot(predm6 ~ as.factor(Habitat2),  data = newdat, ylab = "",  xlab = "", col = "white", yaxt = "n")
axis(4)

dev.off()

