## 6th Dec 2021

## The purpose of this script is to re-analyse the Bat monitoring data on an 
##  hourly basis using stacked data. This script builds on and ammends "ZeroInflation.R"

#############################################################################

#set up space
rm(list=ls())
setwd("R:/R5001-6000/R5901-5950/5913 CH Best practice bat monitoring")


#import data and packages
library(pscl) ## for Zero Inflation models
library(caret)## suggested by reviewer two for prediction success measures
library(corrplot) ## for correlation plots
library(RColorBrewer)
library(ggplot2)
library(lmtest)##likelihood ratio test
require(glmmTMB) ### ZI with random effects
library(lme4) ###linear mixel effects models for the null
library(insight) ### these two work our the r2 of glmmTMB objects and deviance
library(performance)


d <-read.csv("./WX analysis 2/WX3 plus difference corrected_21_zeroes added_stacked.csv")

########################################################
################ predictor selection ###################
########################################################
M <-cor(na.omit(d[c(12, 14, 34:44,55:59)])) 

pdf("./Justyna Analyses/predictor_correlations_hr.pdf")
corrplot(M, type = "upper", order = "hclust",
         col = brewer.pal(n = 8, name="RdYlBu"),
         addCoef.col = 'grey', tl.cex=0.5, number.cex = 0.7)
dev.off()

pdf("./Justyna Analyses/trends_env_hr2.pdf")
par(mfrow = c(3,3))
for (i in names(d[c(12, 14, 34:44,55:59)]) ){
  plot(Bat_passes_hr ~ d[[i]], 
       xlab = i, pch = 16,
       data = d)
}
dev.off()

plot(Bat_passes_hr~Complete_hrs_since_sunset, data = d) ## checking to see whether to begin with a polynomial term for time since sunset

####dataset correction
d2 <- d[complete.cases(d$Temp_hr), ]###need to subset data to exclude NAs in temp_hr to make polynomial work 
d2$Location <- as.factor(d2$Location)

###data limitation #### with only Dec- April data
d3 <- d2[d2$Month != 5,]
d3 <- d3[d3$Month != 6,]
d3 <- d3[d3$Month != 7,]
d3 <- d3[d3$Month != 8,]
d3 <- d3[d3$Month != 9,]
d3 <- d3[d3$Month != 10,]
d3 <- d3[d3$Month != 11,]
d3 <- d3[d3$Complete_hrs_since_sunset < 8,] ### with only first 8 hours of the night

#############################################################
#################### FULL HOURLY DATA SET ###################
#############################################################

##building full model with hand selected representatives of each grouping. 
##then dropping terms
########################################################


a1 <- glmmTMB(
  Bat_passes_hr ~ poly(Temp_hr,2) + Wind_speed_hr+ Rain_hr + RH_hr + poly(Complete_hrs_since_sunset,2) + 
    (1|Location),
  zi = ~ Temp_hr + Wind_speed_hr+ Rain_hr + RH_hr+ 
    as.factor(Habitat2) + Complete_hrs_since_sunset,
  data = d3,
  family = poisson)
summary(a1) ## removing rain_hr from ZI

a2 <- glmmTMB(
  Bat_passes_hr ~ poly(Temp_hr,2) + Wind_speed_hr+ Rain_hr + RH_hr + poly(Complete_hrs_since_sunset,2) + 
    (1|Location),
  zi = ~ Temp_hr + Wind_speed_hr+  RH_hr+ 
    as.factor(Habitat2) + Complete_hrs_since_sunset,
  data = d3,
  family = poisson)
summary(a2) ##removing rain_hr from count


a3 <- glmmTMB(
  Bat_passes_hr ~ poly(Temp_hr,2) + Wind_speed_hr+  RH_hr + poly(Complete_hrs_since_sunset,2) + 
    (1|Location),
  zi = ~ Temp_hr + Wind_speed_hr+  RH_hr+ 
    as.factor(Habitat2) + Complete_hrs_since_sunset,
  data = d3,
  family = poisson)
summary(a3)  ## removing hours from sunset fdrom ZI

a3 <- glmmTMB(
  Bat_passes_hr ~ poly(Temp_hr,2) + Wind_speed_hr+  RH_hr + poly(Complete_hrs_since_sunset,2) + 
    (1|Location),
  zi = ~ Temp_hr + Wind_speed_hr+  RH_hr+ 
    as.factor(Habitat2) ,
  data = d3,
  family = poisson)
summary(a3) ### wind _ speed hr from ZI

a4 <- glmmTMB(
  Bat_passes_hr ~ poly(Temp_hr,2) + Wind_speed_hr+  RH_hr + poly(Complete_hrs_since_sunset,2) + 
    (1|Location),
  zi = ~ Temp_hr +  RH_hr+ 
    as.factor(Habitat2) ,
  data = d3,
  family = poisson)
summary(a4) ##RH_hr from ZI


a5 <- glmmTMB(
  Bat_passes_hr ~ poly(Temp_hr,2) + Wind_speed_hr+  RH_hr + poly(Complete_hrs_since_sunset,2) + 
    (1|Location),
  zi = ~ Temp_hr +
    as.factor(Habitat2) ,
  data = d3,
  family = poisson)
summary(a5) ##Temp hr from ZI

a6 <- glmmTMB(
  Bat_passes_hr ~ poly(Temp_hr,2) + Wind_speed_hr+  RH_hr + poly(Complete_hrs_since_sunset,2) + 
    (1|Location),
  zi = ~ 
    as.factor(Habitat2) ,
  data = d3,
  family = poisson)
summary(a6)


a7 <- glmmTMB(
  Bat_passes_hr ~ poly(Temp_hr,2) + Wind_speed_hr+   poly(Complete_hrs_since_sunset,2) + 
    (1|Location),
  zi = ~ 
    as.factor(Habitat2) ,
  data = d3,
  family = poisson)
summary(a7) #### Good! and now checking for polynomials 


a8 <- glmmTMB(
  Bat_passes_hr ~ Temp_hr + Wind_speed_hr+   poly(Complete_hrs_since_sunset,2) + 
    (1|Location),
  zi = ~ 
    as.factor(Habitat2) ,
  data = d3,
  family = poisson)
summary(a8) ###gotta remove temp hr from count in the non-poly one 

a9 <- glmmTMB(
  Bat_passes_hr ~ Wind_speed_hr+   poly(Complete_hrs_since_sunset,2) + 
    (1|Location),
  zi = ~ 
    as.factor(Habitat2) ,
  data = d3,
  family = poisson)
summary(a9) ###ok good for the non-poly temp one 
 

a10 <- glmmTMB(
  Bat_passes_hr ~ poly(Temp_hr,2) + Wind_speed_hr+   Complete_hrs_since_sunset + 
    (1|Location),
  zi = ~ 
    as.factor(Habitat2) ,
  data = d3,
  family = poisson)
summary(a10) ###gotta remove complete_hrs from count 

a11 <- glmmTMB(
  Bat_passes_hr ~ poly(Temp_hr,2) + Wind_speed_hr+
    (1|Location),
  zi = ~ 
    as.factor(Habitat2) ,
  data = d3,
  family = poisson)
summary(a11)

################ MODEL TESTING  
##build null model
summary(mnull <-  glmer(Bat_passes_hr ~ poly(Temp_hr,2) + Wind_speed_hr+   poly(Complete_hrs_since_sunset,2) + 
                          (1|Location), ###this is a7 structure
                      family = "poisson", 
                      data = d3))

compare_performance(a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11,mnull) #####a7 is the best 
r2(a7) 
summary(a7)
    #Marginal R2 provides the variance explained only by fixed effects and conditional R2 provides the 
    #variance explained by the entire model, i.e., both fixed effects and random effects.

#################################################################
###### plotting outputs #########################################
#################################################################

d3$preda7 <-  predict(a7,d3, type = "response")  

pdf("./Justyna Analyses/a7a_predictions.pdf")

#par (mfrow = c (4,3), cex=0.7, mai = c(1, 0.3, 0.2, 0.1)+ 0.1)
par (mfrow = c (4,3))

par(mai=c(1, 0.6, 0.2, 0.1))
plot(Bat_passes_hr ~ Temp_hr , ylab = "Passes/hr",  xlab = "", main = "Observations", pch = 16, data = d3)
par(mai=c(1, 0.3, 0.2, 0.5))
plot(factor(Bat_passes_hr > 0, levels = c(FALSE, TRUE), labels = c("=0", ">0")) ~ Temp_hr,
     data = d3, ylab = "", xlab = expression(paste("Temperature (", degree, "C)")), main = "Zero inflation", col = "white")
par(mai=c(1, 0, 0.2, 0.5))
plot(preda7 ~ Temp_hr,  data = d3, ylab = "", xlab = "", main = "Model predictions", yaxt = "n")
axis(4)


par(mai=c(1, 0.6, 0.2, 0.1))
plot(Bat_passes_hr ~ Wind_speed_hr , ylab = "Passes/hr",  xlab = "",  pch = 16, data = d3)
par(mai=c(1, 0.3, 0.2, 0.5))
plot(factor(Bat_passes_hr > 0, levels = c(FALSE, TRUE), labels = c("=0", ">0")) ~ Wind_speed_hr,
     data = d3, ylab = "", xlab = expression("Wind speed (kmh"^ -1 ~")"), col = "white")
par(mai=c(1, 0, 0.2, 0.5))
plot(preda7 ~ Wind_speed_hr,  data = d3, ylab = "", xlab = "", yaxt = "n")
axis(4)

par(mai=c(1, 0.6, 0.2, 0.1))
plot(Bat_passes_hr ~ as.factor(Complete_hrs_since_sunset), ylab = "Passes/hr",  xlab = "",  pch = 16, data = d3)
par(mai=c(1, 0.3, 0.2, 0.5))
plot(factor(Bat_passes_hr > 0, levels = c(FALSE, TRUE), labels = c("=0", ">0")) ~ as.factor(Complete_hrs_since_sunset),
     data = d3, ylab = "", xlab = "Time from sunset (h)", col = "white", yaxt="n")
par(mai=c(1, 0, 0.2, 0.5))
plot(preda7 ~ as.factor(Complete_hrs_since_sunset),  data = d3, ylab = "", xlab = "", yaxt = "n")
axis(4)

par(mai=c(1, 0.6, 0.2, 0.1))
plot(Bat_passes_hr ~ as.factor(Habitat2) , ylab = "Passes/hr",  xlab = "",  pch = 16, data = d3)
par(mai=c(1, 0.3, 0.2, 0.5))
plot(factor(Bat_passes_hr > 0, levels = c(FALSE, TRUE), labels = c("=0", ">0")) ~ as.factor(Habitat2),
     data = d3, ylab = "", xlab = "Habitat type")
par(mai=c(1, 0, 0.2, 0.5))
plot(preda7 ~ as.factor(Habitat2),  data = d3, ylab = "", xlab = "", col = "white", yaxt = "n")
axis(4)

dev.off()

### Edits for reviewer

## correlation between hourly and daily data

d <- read.csv("./WX analysis 2/WX3 plus difference corrected_21_zeroes added.csv")
h <-read.csv("./WX analysis 2/WX3 plus difference corrected_21_zeroes added_stacked.csv")


h <- h[complete.cases(h$Temp_hr), ]
h$Location <- as.factor(h$Location)

h$ID <- paste(h$Date.start, h$Northing, h$Easting)
d$ID <- paste (d$Date.start, d$Northing, d$Easting)


full <- merge (h, d, by = "ID", all = TRUE)

plot(full$Bat_passes_hr, full$Tot.pass.x)
cor(full$Bat_passes_hr, full$Tot.pass.x, use='complete.obs')

plot(full$WSSS, full$Wind_speed_hr)
cor(full$WSSS, full$Wind_speed_hr, use='complete.obs')


plot(full$TSS, full$Temp_hr)
cor(full$TSS, full$Temp_hr, use='complete.obs')
str(full$Tot.da)
plot(full$tot.day_rain.x, full$Rain_hr)
cor(full$tot.day_rain.x, full$Rain_hr, use='complete.obs')
